==> lovebird-1.1.0.tgz: package/README.md <==
<img align="center" src="media/icon.png">

> For the lovebirds but not by lovebird

Falling in love is easy but keeping it alive is hard or sometimes it is better to just let it go. We (Not me ;) geeks are known for failing at it miserably. But no more, we code for every problem in our life then why not this. So geeks, I present you `lovebird`. One stop solution for your love issues from breakup to compliments, lovebird have your back ;) So go ahead fall in love.

## Requirements

- Node.js

## Installation

```sh
npm install -g lovebird
```
## Running lovebird

```sh
$ lovebird
# *********************************************
# *                                           *
# *               LOVEBIRD                    *
# *                                           *
# *********************************************

lovebird$ help

#  Commands:
#
#    help [command...]  Provides help for a given command.
#    exit [options]     Exits instance of Vorpal.
#    excuse             Best excuses to get out of relationship
#    reaction           Reaction for dummies who got dumped.
#    compliment         Say something nice and save your ass.

lovebird$ excuse

# 💔💔  I Just Need A Little Space.

lovebird$ reaction

# 🙌🙌  I can’t believe this.

lovebird$ compliment

# 😻😻  You make me feel like it's summer.

lovebird$ gift

# 😻😻   Star Wars Lightsaber Candlestick.

```

## Commands

- [x] `excuse` (Best excuses to get out of relationship)
- [x] `reaction` (Reaction for dummies who got dumped)
- [ ] `compliments` (Say something nice and save your ass)


## Author
[Ravi Suhag](http://www.ravisuhag.com)

==> lovebird-1.1.1.tgz: package/README.md <==
<img align="center" src="media/icon.png">

> For the lovebirds but not by lovebird

Falling in love is easy but keeping it alive is hard or sometimes it is better to just let it go. We (Not me ;) geeks are known for failing at it miserably. But no more, we code for every problem in our life then why not this. So geeks, I present you `lovebird`. One stop solution for your love issues from breakup to compliments, lovebird have your back ;) So go ahead fall in love.

## Requirements

- Node.js

## Installation

```sh
npm install -g lovebird
```
## Running lovebird

```sh
$ lovebird
# *********************************************
# *                                           *
# *               LOVEBIRD                    *
# *                                           *
# *********************************************

lovebird$ help

#  Commands:
#
#    help [command...]  Provides help for a given command.
#    exit [options]     Exits instance of Vorpal.
#    excuse             Best excuses to get out of relationship
#    reaction           Reaction for dummies who got dumped.
#    compliment         Say something nice and save your ass.
```

#### `excuse` : best excuses to get out of relationship

```sh
lovebird$ excuse

# 💔💔  I Just Need A Little Space.
```

#### `reaction` : reaction for dummies who just got dumped

```sh
lovebird$ reaction

# 🙌🙌  I can’t believe this.
```

#### `compliment` : say something nice and save your ass

```sh
lovebird$ compliment

# 😻😻  You make me feel like it's summer.
```

#### `gifts` : give something nice and save your ass

```sh
lovebird$ gift

# 😻😻   Star Wars Lightsaber Candlestick.
```

## Commands

- [x] `excuse` (Best excuses to get out of relationship)
- [x] `reaction` (Reaction for dummies who got dumped)
- [x] `compliments` (Say something nice and save your ass)
- [x] `gifts`  (Give something nice and save your ass.)
- [ ] `propose` (Stop being shy and hit it hard.)
- [ ] `count` (Count the love.)


## Author
[Ravi Suhag](http://www.ravisuhag.com)
